package Alien::TALib;
use strict;
use warnings;

our $VERSION = '0.02';
$VERSION = eval $VERSION;

use parent 'Alien::Base';


1;

__END__
#### COPYRIGHT: Vikas N Kumar. All Rights Reserved
#### AUTHOR: Vikas N Kumar <vikas@cpan.org>
#### DATE: 17th Dec 2013
#### LICENSE: Refer LICENSE file.
